==> haskell-crypton-x509-system-1.6.7-2-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-crypton-x509-system.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 crypton-x509-system
version:              1.6.7
visibility:           public
id:                   crypton-x509-system-1.6.7-Fvv2DKPbfbiEaRrs1qVag5
key:                  crypton-x509-system-1.6.7-Fvv2DKPbfbiEaRrs1qVag5
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             https://github.com/kazu-yamamoto/crypton-certificate
synopsis:             Handle per-operating-system X.509 accessors and storage
description:
    System X.509 handling for accessing operating system dependents store and other storage methods

category:             Data
abi:                  c5a221da40f6c64410cd12da4d914b9a
exposed:              True
exposed-modules:      System.X509 System.X509.MacOS System.X509.Unix
import-dirs:          /usr/lib/ghc-9.0.2/site-local/crypton-x509-system-1.6.7
library-dirs:         /usr/lib/ghc-9.0.2/site-local/crypton-x509-system-1.6.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-crypton-x509-system
hs-libraries:         HScrypton-x509-system-1.6.7-Fvv2DKPbfbiEaRrs1qVag5
depends:
    base-4.15.1.0 bytestring-0.10.12.1 containers-0.6.4.1
    crypton-x509-1.7.6-AvzHaWxATQa7PVyUdSHq4f
    crypton-x509-store-1.6.9-2PJODxtfvT71YNIEM4EDL0 directory-1.3.6.2
    filepath-1.4.2.1 mtl-2.2.2 pem-0.2.4-BPy6FkaN6WZJR1uZcmyWYr
    process-1.6.13.2

haddock-interfaces:
    /usr/share/doc/haskell-crypton-x509-system/html/crypton-x509-system.haddock

haddock-html:         /usr/share/doc/haskell-crypton-x509-system/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-crypton-x509-system-1.6.7-4-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-crypton-x509-system.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 crypton-x509-system
version:              1.6.7
visibility:           public
id:                   crypton-x509-system-1.6.7-I2yVvgPJSqSE6fRuAwhgCM
key:                  crypton-x509-system-1.6.7-I2yVvgPJSqSE6fRuAwhgCM
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             https://github.com/kazu-yamamoto/crypton-certificate
synopsis:             Handle per-operating-system X.509 accessors and storage
description:
    System X.509 handling for accessing operating system dependents store and other storage methods

category:             Data
abi:                  f943d8501ad6a6f3cf411b02f178c2cd
exposed:              True
exposed-modules:      System.X509 System.X509.MacOS System.X509.Unix
import-dirs:          /usr/lib/ghc-9.0.2/site-local/crypton-x509-system-1.6.7
library-dirs:         /usr/lib/ghc-9.0.2/site-local/crypton-x509-system-1.6.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-crypton-x509-system
hs-libraries:         HScrypton-x509-system-1.6.7-I2yVvgPJSqSE6fRuAwhgCM
depends:
    base-4.15.1.0 bytestring-0.10.12.1 containers-0.6.4.1
    crypton-x509-1.7.6-CzEi2vXw5knL8zorlIO6hD
    crypton-x509-store-1.6.9-H9QxrphP5M0CHtek19ubho directory-1.3.6.2
    filepath-1.4.2.1 mtl-2.2.2 pem-0.2.4-BjVqkyHWrxJJad2ONgFuhg
    process-1.6.13.2

haddock-interfaces:
    /usr/share/doc/haskell-crypton-x509-system/html/crypton-x509-system.haddock

haddock-html:         /usr/share/doc/haskell-crypton-x509-system/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
